@@ -7,19 +7,18 @@ import datetime
 import argparse
 import subprocess
 
-# import pynvml
+import pynvml
 import torch
 import numpy as np
 from gpustat import GPUStatCollection
 
 from ..core import convert_list_str
 
-# NOTE: pynvml is not suitable for python3.5 or lower
-# # init
-# pynvml.nvmlInit()
-# NUM_GPUS = pynvml.nvmlDeviceGetCount()
+# init
+pynvml.nvmlInit()
+NUM_GPUS = pynvml.nvmlDeviceGetCount()
 
-NUM_GPUS = torch.cuda.device_count()
+# NUM_GPUS = torch.cuda.device_count()
 
 
 def get_free_gpu(mode="memory", memory_need=11000) -> list:
@@ -67,13 +66,13 @@ def gpu_check_condition(gpu_stat, mode, memory_need) -> bool:
     else: return False
 
 
-def supervise_gpu(num_gpu=1, memory_need=11000, mode="memory") -> list:
+def supervise_gpu(num_gpu=1, mode="memory", memory_need=11000) -> list:
     r"""Supervise gpu for you need
 
     Args:
         num_gpu (int, optional): The number of gpu you need. Defaults to 1.
-        memory_need (int, optional): The memory you need, used if mode=='memory'. Defaults to 10000.
         mode (str, optional): memory-free or process-free. Defaults to "memory".
+        memory_need (int, optional): The memory you need, used if mode=='memory'. Defaults to 10000.
 
     Returns:
         list: free gpu id list
@@ -89,11 +88,13 @@ def supervise_gpu(num_gpu=1, memory_need=11000, mode="memory") -> list:
     used_gpu_id_list = gpu_free_id_list[:num_gpu]
     return used_gpu_id_list
 
-def set_cuda_visible_devices(gpu_ids=None, num_gpu=1, memory_need=11000):
+def set_cuda_visible_devices(gpu_ids=None, num_gpu=1, mode="memory", memory_need=11000):
     r"""Set cuda visible devices automatically
 
     Args:
         gpu_ids (str | list, optional): specified gpus. Defaults to None.
+        mode (str, optional): memory-free or process-free. Defaults to "memory".
+        memory_need (int, optional): The memory you need, used if mode=='memory'.
         num_gpu (int, optional):
             the num of gpus you want to use. Defaults to 1.
             (useless if `gpu_ids` is not None)
@@ -102,7 +103,7 @@ def set_cuda_visible_devices(gpu_ids=None, num_gpu=1, memory_need=11000):
         if not isinstance(gpu_ids, list):
             gpu_ids = [gpu_ids]
     elif gpu_ids is None and num_gpu >= 1: # not specify gpus
-        gpu_ids = supervise_gpu(num_gpu, memory_need)
+        gpu_ids = supervise_gpu(num_gpu, mode, memory_need)
     else:
         raise ValueError("`num_gpu` is invalid: {}, it must '>=1'".format(num_gpu))
     
