@@ -1,5 +1,7 @@
 # Copyright (c) Gorilla-Lab. All rights reserved.
 
+import os
+import os.path as osp
 import logging
 
 import torch.distributed as dist
@@ -58,6 +60,8 @@ def get_logger(name, log_file=None, log_level=logging.INFO):
 
     # only rank 0 will add a FileHandler
     if rank == 0 and log_file is not None:
+        if not osp.isdir(osp.dirname(log_file)):
+            os.makedirs(osp.dirname(log_file))
         file_handler = logging.FileHandler(log_file, "w")
         handlers.append(file_handler)
 
